@@ -121,8 +121,8 @@ arma::mat try_inv(arma::mat M,int nvar)
   arma::mat Minv;
   try
   {
-    std::ostream nullstream(0);
-    arma::set_cerr_stream(nullstream);
+    // std::ostream nullstream(0);
+    // arma::set_cerr_stream(nullstream);
     //Minv = pinv(M);
     //M = try_clip(M,nvar,1);
     Minv = inv(M); //Minv = inv(M,"std");
@@ -140,8 +140,8 @@ arma::mat try_solve(arma::mat M,arma::mat V)
   arma::mat Msolve;
   try
   {
-    std::ostream nullstream(0);
-    arma::set_cerr_stream(nullstream);
+    // std::ostream nullstream(0);
+    // arma::set_cerr_stream(nullstream);
     //M = try_clip(M,nvar,1);
     Msolve = solve(M,V); //Msolve = solve(M,V,"std");
     //Msolve = pinv(M)*V;
@@ -175,8 +175,8 @@ double logdet(arma::mat A)
   double sign = 1;
   try
   {
-    std::ostream nullstream(0);
-    arma::set_cerr_stream(nullstream);
+    // std::ostream nullstream(0);
+    // arma::set_cerr_stream(nullstream);
     log_det(val,sign,A);
     return val;
   }
